@@ -35,6 +35,7 @@ from pyvo.io.vosi.vodataservice import TableParam
 from astropy.coordinates import SkyCoord
 from astropy.time import Time
 from astropy.units import Quantity, Unit
+import numpy as np
 
 from .query import DALResults, DALQuery, DALService, Record
 from .mimetype import mime2extension
@@ -505,10 +506,18 @@ class SIAQuery(DALQuery):
     def format(self, format_):
         setattr(self, "_format", format_)
 
-        if isinstance(format_, (str, bytes)):
-            format_ = [format_]
+        if not isinstance(format_, list):
+            format_ = format_.split(',')
+        normalized_formats = []
+        for user_input in format_:
+            if user_input.upper() in ['ALL', 'METADATA', 'GRAPHIC', 'GRAPHIC-ALL']:
+                normalized_formats.append(user_input.upper())
+            elif user_input.split('-')[0].upper() == 'GRAPHIC':
+                normalized_formats.append(user_input.split('-')[0].upper()+"-"+user_input.split('-')[1])
+            else:
+                normalized_formats.append(user_input)
 
-        self["FORMAT"] = ",".join(_.upper() for _ in format_)
+        self["FORMAT"] = ",".join(normalized_formats)
 
     @format.deleter
     def format(self):
@@ -702,10 +711,13 @@ class SIARecord(SodaRecordMixin, DatalinkRecordMixin, Record):
         as an astropy.time.Time instance
         """
         dateobs = self.getbyucd("VOX:Image_MJDateObs")
-        if dateobs:
-            return Time(dateobs, format="mjd")
-        else:
-            return None
+        try:
+            if not dateobs or np.isnan(dateobs):
+                return None
+        except TypeError:
+            # np.isnan can only check floats. If can't check for nan, pass it along
+            pass
+        return Time(dateobs, format="mjd")
 
     @property
     def naxes(self):
