@@ -3,9 +3,6 @@
 """
 Tests for pyvo.dal.scs
 """
-from __future__ import (
-    absolute_import, division, print_function, unicode_literals)
-
 from functools import partial
 import re
 
@@ -35,12 +32,12 @@ def scs(mocker):
 @pytest.mark.usefixtures('scs')
 @pytest.mark.filterwarnings("ignore::astropy.io.votable.exceptions.W06")
 def test_search():
-    results = search('http://example.com/scs', (78, 2), 0.5)
+    results = search('http://example.com/scs', pos=(78, 2), radius=0.5)
 
     assert len(results) == 1273
 
 
-class TestSCSService(object):
+class TestSCSService:
     def test_init(self):
         service = SCSService('http://example.com/scs')
 
@@ -51,6 +48,6 @@ class TestSCSService(object):
     def test_search(self):
         service = SCSService('http://example.com/scs')
 
-        results = service.search((78, 2), 0.5)
+        results = service.search(pos=(78, 2), radius=0.5)
 
         assert len(results) == 1273
