@@ -14,10 +14,11 @@ import pytest
 import requests_mock
 
 from pyvo.dal.tap import escape, search, AsyncTAPJob, TAPService
-from pyvo.dal import DALQueryError
+from pyvo.dal import DALQueryError, DALServiceError
 
 from pyvo.io.uws import JobFile
 from pyvo.io.uws.tree import Parameter, Result, ErrorSummary, Message
+from pyvo.io.vosi.exceptions import VOSIError
 from pyvo.utils import prototype
 
 from astropy.time import Time, TimeDelta
@@ -386,10 +387,16 @@ def tables(mocker):
 @pytest.fixture()
 def examples(mocker):
     def callback_examplesXHTML(request, context):
-        return get_pkg_data_contents('data/tap/examples.htm')
+        uri = f"://{request.netloc}{request.path}"
+        if uri == '://example.com/tap/examples':
+            return get_pkg_data_contents('data/tap/examples.htm')
+        elif uri == '://example.org/obscore-examples.html':
+            return get_pkg_data_contents('data/tap/obscore-examples.html')
+        else:
+            assert False, f"Unexpected examples URI: {uri}"
 
     with mocker.register_uri(
-        'GET', 'http://example.com/tap/examples', content=callback_examplesXHTML
+        'GET', requests_mock.ANY, content=callback_examplesXHTML
     ) as matcher:
         yield matcher
 
@@ -405,6 +412,17 @@ def capabilities(mocker):
         yield matcher
 
 
+@pytest.fixture()
+def tapservice(capabilities):
+    """
+    preferably use this fixture when you need a generic TAP service;
+    it saves a bit of parsing overhead.
+
+    (but of course make sure you don't modify it).
+    """
+    return TAPService('http://example.com/tap')
+
+
 def test_escape():
     query = 'SELECT * FROM ivoa.obscore WHERE dataproduct_type = {}'
     query = query.format(escape("'image'"))
@@ -442,11 +460,18 @@ class TestTAPService:
 
         assert list(vositables.keys()) == ['test.table1', 'test.table2']
 
+        assert "test.table1" in vositables
+        assert "any.random.stuff" not in vositables
+
         table1, table2 = list(vositables)
         self._test_tables(table1, table2)
 
-    def _test_examples(self, exampleXHTML):
-        assert "SELECT * FROM rosmaster" in exampleXHTML[0]['QUERY']
+    def _test_examples(self, parsed_examples):
+        assert len(parsed_examples) == 6
+        assert "SELECT * FROM rosmaster" in parsed_examples[0]['QUERY']
+        # the last query is from the continuation
+        assert parsed_examples[-1]['QUERY'].startswith(
+            "\nSELECT access_url, t_exptime, t_min FROM ivoa.obscore")
 
     @pytest.mark.usefixtures('examples')
     def test_examples(self):
@@ -598,7 +623,7 @@ class TestTAPService:
         #       - 1 job for after attribute
         # Tests consists in counting the cumulative number of jobs as per
         # above rules
-        after = datetime.datetime.now()
+        after = datetime.datetime.now(tz=datetime.timezone.utc)
         assert len(service.get_job_list()) == 0
         assert len(service.get_job_list(last=3)) == 3
         assert len(service.get_job_list(after='2018-04-25T17:46:01Z')) == 1
@@ -609,7 +634,7 @@ class TestTAPService:
                                         last=3)) == 4
         assert len(service.get_job_list(phases=['EXECUTING'], last=3)) == 5
         assert len(service.get_job_list(phases=['EXECUTING'], last=3,
-                                        after=datetime.datetime.now())) == 6
+                                        after=datetime.datetime.now(tz=datetime.timezone.utc))) == 6
 
     @pytest.mark.usefixtures('create_fixture')
     def test_create_table(self):
@@ -707,3 +732,57 @@ class TestTAPService:
                                              unique=True)
         finally:
             prototype.deactivate_features('cadc-tb-upload')
+
+
+@pytest.mark.usefixtures("tapservice")
+class TestTAPCapabilities:
+    def test_no_tap_cap(self):
+        svc = TAPService('http://example.com/tap')
+        svc.capabilities = []
+        with pytest.raises(DALServiceError) as excinfo:
+            svc.get_tap_capability()
+        assert str(excinfo.value) == ("Invalid TAP service:"
+            " Does not expose a tr:TableAccess capability")
+
+    def test_no_adql(self):
+        svc = TAPService('http://example.com/tap')
+        svc.get_tap_capability()._languages = []
+        with pytest.raises(VOSIError) as excinfo:
+            svc.get_tap_capability().get_adql()
+        assert str(excinfo.value) == ("Invalid TAP service:"
+            " Does not declare an ADQL language")
+
+    def test_get_adql(self, tapservice):
+        assert tapservice.get_tap_capability().get_adql().name == "ADQL"
+
+    def test_missing_featurelist(self, tapservice):
+        assert (
+            tapservice.get_tap_capability().get_adql().get_feature_list("fump")
+            == [])
+
+    def test_get_featurelist(self, tapservice):
+        features = tapservice.get_tap_capability().get_adql().get_feature_list(
+            "ivo://ivoa.net/std/TAPRegExt#features-adqlgeo")
+        assert set(f.form for f in features) == {
+            'CENTROID', 'CONTAINS', 'COORD1', 'POLYGON',
+            'INTERSECTS', 'COORD2', 'BOX', 'AREA', 'DISTANCE',
+            'REGION', 'CIRCLE', 'POINT'}
+
+    def test_get_missing_feature(self, tapservice):
+        assert tapservice.get_tap_capability().get_adql().get_feature(
+            "ivo://ivoa.net/std/TAPRegExt#features-adqlgeo",
+            "Garage") is None
+
+    def test_get_feature(self, tapservice):
+        feature = tapservice.get_tap_capability().get_adql().get_feature(
+            "ivo://ivoa.net/std/TAPRegExt#features-adqlgeo",
+            "AREA")
+        assert feature.form == "AREA"
+        assert feature.description is None
+
+    def test_missing_udf(self, tapservice):
+        assert tapservice.get_tap_capability().get_adql().get_udf("duff function") is None
+
+    def test_get_udf(self, tapservice):
+        func = tapservice.get_tap_capability().get_adql().get_udf("IVO_hasword")  # case insensitive!
+        assert func.form == "ivo_hasword(haystack TEXT, needle TEXT) -> INTEGER"
