@@ -170,7 +170,7 @@ def search(*constraints: rtcons.Constraint,
 
     The function accepts query constraints either as Constraint objects
     passed in as positional arguments or as their associated keywords.
-    For what constraints are available, see ref:`registry_basic_interface`.
+    For what constraints are available, see :ref:`registry-basic-interface`.
 
 
     The values of keyword arguments may be tuples or lists when the associated
@@ -181,7 +181,7 @@ def search(*constraints: rtcons.Constraint,
 
     Parameters
     ----------
-    *constraints : `rtcons.Constraint` instances
+    *constraints : `~pyvo.registry.Constraint` instances
         The constraints (keywords to match, positions to cover, ...)
         that the returned records need to satisfy.
         The accepted constraints are:
@@ -228,18 +228,15 @@ def search(*constraints: rtcons.Constraint,
         are not reproducible.
 
     **kwargs : strings, mostly
-        shorthands for `constraints`; see the documentation of
+        shorthands for ``constraints``; see the documentation of
         a specific constraint for what keyword it uses and what literal
         it expects.
 
     Returns
     -------
-    RegistryResults
+    ~pyvo.registry.regtap.RegistryResults`
        a container holding a table of matching resource (e.g. services)
 
-    See Also
-    --------
-    RegistryResults
     """
     service = get_RegTAP_service()
     query = RegistryQuery(
@@ -487,8 +484,7 @@ class RegistryResource(dalq.Record):
         (f"\n  ivo_string_agg(COALESCE(intf_type, ''), '{TOKEN_SEP}')",
             "intf_types"),
         (f"\n  ivo_string_agg(COALESCE(intf_role, ''), '{TOKEN_SEP}')",
-            "intf_roles"),
-        "alt_identifier"]
+            "intf_roles")]
 
     def __init__(self, results, index, session=None):
         dalq.Record.__init__(self, results, index, session=session)
@@ -571,9 +567,6 @@ class RegistryResource(dalq.Record):
         """
         the textual description of the resource.
 
-        See Also
-        --------
-        SimpleResource.describe
         """
         return self.get("res_description", decode=True)
 
@@ -584,14 +577,6 @@ class RegistryResource(dalq.Record):
         """
         return self.get("reference_url", decode=True)
 
-    @property
-    def alt_identifier(self):
-        """Alternative identifier.
-
-        It is often used to provide the resource associated DOI.
-        """
-        return self.get("alt_identifier", decode=True)
-
     @property
     def creators(self):
         """
@@ -935,8 +920,14 @@ class RegistryResource(dalq.Record):
                 else:
                     print(f"Authors: {', '.join(creators[:nmax_authors])} et al.\n"
                     "See creators attribute for the complete list of authors.", file=file)
-            if self.alt_identifier:
-                print(f"Alternative identifier: {self.alt_identifier}", file=file)
+
+            alt_identifiers = self.get_alt_identifiers()
+            if alt_identifiers:
+                print(
+                    "Alternative identifier(s): {}".format(
+                        ", ".join(alt_identifiers)),
+                    file=file)
+
             if self.reference_url:
                 print("More info: " + self.reference_url, file=file)
 
@@ -965,6 +956,17 @@ class RegistryResource(dalq.Record):
 
         return "\n".join(contacts)
 
+    def get_alt_identifiers(self):
+        """return a sequence of non-ivoid identifiers for the resource.
+
+        This is typically used to provide a DOI for the resource.
+        """
+        res = get_RegTAP_service().run_sync("""
+            SELECT alt_identifier
+            FROM rr.alt_identifier
+            WHERE ivoid={}""".format(rtcons.make_sql_literal(self.ivoid)))
+        return [r["alt_identifier"] for r in res]
+
     def _build_vosi_column(self, column_row):
         """
         return a io.vosi.vodataservice.Column element for a
