@@ -449,8 +449,7 @@ class TestSelectClause:
             "\n  ivo_string_agg(COALESCE(access_url, ''), ':::py VO sep:::') AS access_urls, "
             "\n  ivo_string_agg(COALESCE(standard_id, ''), ':::py VO sep:::') AS standard_ids, "
             "\n  ivo_string_agg(COALESCE(intf_type, ''), ':::py VO sep:::') AS intf_types, "
-            "\n  ivo_string_agg(COALESCE(intf_role, ''), ':::py VO sep:::') AS intf_roles, "
-            "alt_identifier")
+            "\n  ivo_string_agg(COALESCE(intf_role, ''), ':::py VO sep:::') AS intf_roles")
 
     def test_group_by_columns(self):
         # Again, this will break as regtap.RegistryResource.expected_columns
@@ -471,5 +470,41 @@ class TestSelectClause:
                     "source_format, "
                     "source_value, "
                     "region_of_regard, "
-                    "waveband, "
-                    "alt_identifier"))
+                    "waveband"))
+
+    def test_joined_tables(self):
+        expected_tables = [
+            # from author constraint
+            "rr.res_role",
+            # default tables
+            "rr.resource",
+            "rr.capability",
+            "rr.interface",
+        ]
+        assert all(table in _build_regtap_query_with_fake([rtcons.Author("%Hubble%")])
+                   for table in expected_tables)
+
+
+@pytest.mark.remote_data
+def test_all_constraints():
+    text = rtcons.Freetext("star")
+    author = rtcons.Author(r"%ESA%")
+    servicetype = rtcons.Servicetype("tap")
+    waveband = rtcons.Waveband("optical")
+    datamodel = rtcons.Datamodel("obscore")
+    ivoid = rtcons.Ivoid(r"ivoid")
+    ucd = rtcons.UCD(r"pos.eq.ra")
+    moc = rtcons.Spatial("0/0-11", intersect="overlaps")
+    spectral = rtcons.Spectral((5000 * u.Angstrom, 6000 * u.Angstrom))
+    time = rtcons.Temporal((50000, 60000))
+    result = registry.search(
+        text, author, servicetype, waveband, datamodel,
+        ivoid, ucd, moc, spectral, time
+    )
+    assert result.fieldnames == (
+        'ivoid', 'res_type', 'short_name',
+        'res_title', 'content_level', 'res_description',
+        'reference_url', 'creator_seq', 'created', 'updated',
+        'rights', 'content_type', 'source_format', 'source_value',
+        'region_of_regard', 'waveband', 'access_urls', 'standard_ids',
+        'intf_types', 'intf_roles')
